==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate2/ts/Rotate2_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Rotate2</name>
    <message>
        <location filename="../Rotate2.js" line="+67"/>
        <source>Center of primary rotation</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Ośrodek podstawowej rotacji</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Center of secondary rotation</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Centrum wtórnego obrotu</translation>
    </message>
    <message>
        <location filename="../Rotate2Init.js" line="+2"/>
        <source>Rotate T&amp;wo</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Obróć &amp;dwa</translatorcomment>
        <translation type="unfinished">Obróć &amp;dwa</translation>
    </message>
    <message>
        <location filename="../Rotate2.ui" line="+17"/>
        <source>Primary Angle:</source>
        <translation type="unfinished">Główny Angle:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Secondary Angle:</source>
        <translation type="unfinished">Secondary Angle:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Copies:</source>
        <translation type="unfinished">Kopie:</translation>
    </message>
</context>
<context>
    <name>Rotate2Options</name>
    <message>
        <location filename="../Rotate2Dialog.ui" line="+14"/>
        <source>Rotate Two Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje obrotów podwójnych</translatorcomment>
        <translation type="unfinished">Opcje obrotów podwójnych</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation type="unfinished">Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation type="unfinished">&amp;Usuń oryginał</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation type="unfinished">&amp;Zachowaj oryginał</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation type="unfinished">Kopie &amp;wielokrotne</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>Angle (&amp;a):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kąt (&amp;a):</translatorcomment>
        <translation type="unfinished">Kąt (&amp;a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle (&amp;b):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kąt (&amp;b):</translatorcomment>
        <translation type="unfinished">Kąt (&amp;b):</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Użyj bieżącej warstwy i atrybuty</translation>
    </message>
</context>
<context>
    <name>TranslateRotate</name>
    <message>
        <source>Primary Angle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Główny Angle:</translation>
    </message>
    <message>
        <source>Secondary Angle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Secondary Angle:</translation>
    </message>
    <message>
        <source>Copies:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Kopie &amp;wielokrotne:
Kopie wielokrotne:
Kopie:</translatorcomment>
        <translation type="obsolete">Kopie:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate2/ts/Rotate2_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Rotate2</name>
    <message>
        <location filename="../Rotate2.js" line="+67"/>
        <source>Center of primary rotation</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Środek głównego obrotu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Center of secondary rotation</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Środek wtórnego obrotu</translation>
    </message>
    <message>
        <location filename="../Rotate2Init.js" line="+2"/>
        <source>Rotate T&amp;wo</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Obróć &amp;dwa</translatorcomment>
        <translation>Obróć &amp;dwukrotnie</translation>
    </message>
    <message>
        <location filename="../Rotate2.ui" line="+17"/>
        <source>Primary Angle:</source>
        <translation>Główny kąt:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Secondary Angle:</source>
        <translation>Wtórny kąt</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Copies:</source>
        <translation>Liczba kopii:</translation>
    </message>
</context>
<context>
    <name>Rotate2Options</name>
    <message>
        <location filename="../Rotate2Dialog.ui" line="+14"/>
        <source>Rotate Two Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje obrotów podwójnych</translatorcomment>
        <translation>Opcje dwukrotnego obrotu</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation>Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation>&amp;Usunięcie oryginału</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation>&amp;Zachowanie oryginału</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation>&amp;Wielokrotne skopiowanie</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>Angle (&amp;a):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kąt (&amp;a):</translatorcomment>
        <translation>Kąt (&amp;a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle (&amp;b):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kąt (&amp;b):</translatorcomment>
        <translation>Kąt (&amp;b):</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Użycie aktualnej warstwy i &amp;atrybutów</translation>
    </message>
</context>
<context>
    <name>TranslateRotate</name>
    <message>
        <source>Primary Angle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Główny Angle:</translation>
    </message>
    <message>
        <source>Secondary Angle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Secondary Angle:</translation>
    </message>
    <message>
        <source>Copies:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Kopie &amp;wielokrotne:
Kopie wielokrotne:
Kopie:</translatorcomment>
        <translation type="obsolete">Kopie:</translation>
    </message>
</context>
</TS>
